@@ -11,12 +11,10 @@ from rich.markdown import Markdown
 from autocoder_nano.actypes import AutoCoderArgs, SourceCodeList, SingleOutputMeta
 from autocoder_nano.agent.agent_base import BaseAgent
 from autocoder_nano.agent.agentic_edit_tools import (  # Import specific resolvers
-    BaseToolResolver,
-    ExecuteCommandToolResolver, ReadFileToolResolver,
+    BaseToolResolver, ReadFileToolResolver,
     SearchFilesToolResolver, ListFilesToolResolver,
-    ListCodeDefinitionNamesToolResolver, AskFollowupQuestionToolResolver,
-    AttemptCompletionToolResolver, PlanModeRespondToolResolver,
-    RecordMemoryToolResolver, RecallMemoryToolResolver
+    AskFollowupQuestionToolResolver,
+    AttemptCompletionToolResolver
 )
 from autocoder_nano.agent.agentic_edit_types import *
 from autocoder_nano.context import get_context_manager, ConversationsPruner
@@ -32,16 +30,11 @@ printer = Printer()
 
 # Map Pydantic Tool Models to their Resolver Classes
 ASK_TOOL_RESOLVER_MAP: Dict[Type[BaseTool], Type[BaseToolResolver]] = {
-    ExecuteCommandTool: ExecuteCommandToolResolver,
     ReadFileTool: ReadFileToolResolver,
     SearchFilesTool: SearchFilesToolResolver,
     ListFilesTool: ListFilesToolResolver,
-    ListCodeDefinitionNamesTool: ListCodeDefinitionNamesToolResolver,
     AskFollowupQuestionTool: AskFollowupQuestionToolResolver,
-    AttemptCompletionTool: AttemptCompletionToolResolver,  # Will stop the loop anyway
-    PlanModeRespondTool: PlanModeRespondToolResolver,
-    RecordMemoryTool: RecordMemoryToolResolver,
-    RecallMemoryTool: RecallMemoryToolResolver
+    AttemptCompletionTool: AttemptCompletionToolResolver
 }
 
 
@@ -148,49 +141,6 @@ class AgenticAsk(BaseAgent):
 
         # 工具列表
 
-        ## execute_command（执行命令）
-        描述：
-        - 用于在系统上执行 CLI 命令，根据用户操作系统调整命令，并解释命令作用，
-        - 对于命令链，使用适合用户操作系统及shell类型的链式语法，相较于创建可执行脚本，优先执行复杂的 CLI 命令，因为它们更灵活且易于运行。
-        - 命令将在当前工作目录{{current_project}}中执行。
-        参数：
-        - command（必填）：要执行的 CLI 命令。该命令应适用于当前操作系统，且需正确格式化，不得包含任何有害指令。
-        - requires_approval（必填）：
-            * 布尔值，此命令表示在用户启用自动批准模式的情况下是否还需要明确的用户批准。
-            * 对于可能产生影响的操作，如安装/卸载软件包，删除/覆盖文件，系统配置更改，网络操作或任何可能产生影响的命令，设置为 'true'。
-            * 对于安全操作，如读取文件/目录、运行开发服务器、构建项目和其他非破坏性操作，设置为 'false'。
-        用法说明：
-        <execute_command>
-        <command>需要运行的命令</command>
-        <requires_approval>true 或 false</requires_approval>
-        </execute_command>
-        用法示例：
-        场景一：安全操作（无需批准）
-        目标：查看当前项目目录下的文件列表。
-        思维过程：这是一个非破坏性操作，requires_approval设置为false。我们需要使用 ls -al 命令，它能提供详细的文件信息。
-        <execute_command>
-        <command>ls -al</command>
-        <requires_approval>false</requires_approval>
-        </execute_command>
-        场景二：复杂命令链（无需批准）
-        目标：查看当前项目目录下包含特定关键词的文件列表
-        思维过程：
-            - 只读操作，不会修改任何文件，requires_approval设置为false。
-            - 为了在项目文件中递归查找关键词，我们可以使用 grep -Rn 命令。
-            - 同时为了避免搜索无关的目录（如 .git 或 .auto-coder），需要使用--exclude-dir参数进行排除。
-            - 最后通过管道将结果传递给head -10，只显示前10个结果，以确保输出简洁可读
-        <execute_command>
-        <command>grep -Rn --exclude-dir={.auto-coder,.git} "*FunctionName" . | head -10</command>
-        <requires_approval>false</requires_approval>
-        </execute_command>
-        场景三：可能产生影响的操作（需要批准）
-        目标：在项目中安装一个新的npm包axios。
-        思维过程：这是一个安装软件包的操作，会修改node_modules目录和package.json文件。为了安全起见，requires_approval必须设置为true。
-        <execute_command>
-        <command>npm install axios</command>
-        <requires_approval>true</requires_approval>
-        </execute_command>
-
         ## read_file（读取文件）
         描述：
         - 请求读取指定路径文件的内容。
@@ -272,52 +222,6 @@ class AgenticAsk(BaseAgent):
         <recursive>true</recursive>
         </list_files>
 
-        ## record_memory (记录记忆)
-        描述：
-        - 记忆系统，用于存储改需求的最终交付文档
-        参数：
-        - content（必填）：你的记忆正文
-        用法说明：
-        <record_memory>
-        <content>Notebook Content</content>
-        </record_memory>
-        用法示例：
-        场景一：记录任务分析
-        目标：记录对任务需求的初步分析。
-        思维过程：这是一个内部记忆操作，不会影响外部系统，直接将分析内容作为 content 记录。
-        <record_memory>
-        <content>
-        任务分析：
-        需求：在 src/utils.js 文件中添加一个 formatDate 函数。
-        待办：1.检查文件是否存在。2.编写函数实现。3.添加测试用例。
-        </content>
-        </record_memory>
-        场景二：记录执行经验
-        目标：记录在执行某个任务时学到的经验或遇到的问题。
-        思维过程：这是一个内部记忆操作，将解决特定问题的经验作为 content 记录，以便将来参考。
-        <record_memory>
-        <content>
-        经验总结：在处理文件权限问题时，优先使用 chmod 命令而不是 chown，因为前者更易于管理单一文件的权限，而后者可能影响整个目录。
-        </content>
-        </record_memory>
-
-        ## recall_memory (检索记忆)
-        描述：
-        - 检索记忆系统中的信息
-        参数：
-        - query（必填）：你检索记忆的提问，检索记忆时可以使用多个关键词（关键词可以根据任务需求自由发散），且必须使用空格分割关键词
-        用法说明：
-        <recall_memory>
-        <query>Recall Notebook Query</query>
-        </recall_memory>
-        用法示例：
-        场景一：检索之前的任务分析
-        目标：回忆历史上关于 formatDate 函数的所有任务分析记录。
-        思维过程：这是一个内部记忆操作，使用与之前记录相关的关键词进行检索，如 任务分析 和 待办。
-        <recall_memory>
-        <query>任务分析 待办 formatDate</query>
-        </recall_memory>
-
         ## ask_followup_question（提出后续问题）
         描述：
         - 向用户提问获取任务所需信息。
@@ -390,14 +294,10 @@ class AgenticAsk(BaseAgent):
         - 自动标注行业惯例方案供用户确认
 
         # 工具优先级矩阵
-        1. (高) ask_followup_question: 当任务需求不明确或缺少关键信息时，优先使用此工具向用户提问以进行澄清。
-        2. list_files / search_files / read_file: 在生成最终交付方案前，对项目目录结构或文件内容进行探索和信息收集，确保对当前项目有充分了解。
+        1. (高) ask_followup_question 工具: 当任务需求不明确或缺少关键信息时，优先使用此工具向用户提问以进行澄清。
+        2. list_files / search_files / read_file 工具: 在生成最终交付方案前，对项目目录结构或文件内容进行探索和信息收集，确保对当前项目有充分了解。
             - 用户如果提供了明确代码文件名或函数名时，使用 search_files 工具，获取代码位置，相反则使用 list_files 工具进行探索
-        3. record_memory / recall_memory: 用于交付方案的检索与记忆。
-            - 在任务开始执行前，使用 record_memory 检索分析历史交付方案。
-            - 在任务执行完毕后，使用 recall_memory 保存最终交付方案。
-        4. execute_command: 用于执行实际的命令操作，如安装依赖，运行测试等。在收集完所有必要信息并制定好计划后使用。
-        5. (低) attempt_completion: 仅在确认所有任务步骤已成功完成且已取得预期结果后使用，用于向用户展示最终成果。
+        3. (低) attempt_completion 工具: 仅在确认所有任务步骤已成功完成且已取得预期结果后使用，用于向用户展示最终成果。
         """
         return {
             "current_project": os.path.abspath(self.args.source_dir)
@@ -632,9 +532,8 @@ class AgenticAsk(BaseAgent):
         ```
 
         4. 汇总审批阶段
-        - 这是整个工作流的最后一步，你需要将需求澄清文档，系统设计文档，任务拆解文档，整体合并为最终交付文档
-        - 向用户展示最终交付文档，并询问用户该方案是否OK
-        - 如果用户通过则调用 record_memory 工具记录该方案，不通过则按用户需求继续修改
+        - 这是整个工作流的最后一步，你需要将需求澄清文档，系统设计文档，任务拆解文档，整体合并为最终交付文档，并询问用户该方案是否OK
+        - 最后使用 attempt_completion 工具向用户展示最终交付文档
         """
 
     @prompt()
@@ -665,7 +564,7 @@ class AgenticAsk(BaseAgent):
 
         1. 输出格式：你的最终输出交付文档，清晰地包含以下三个部分：需求澄清文档，系统设计文档，任务拆解文档。
         2. 用户控制：每一个关键点都需要用户确认OK
-        3. 保存方式：最终交付文档通过 record_memory 工具记录，整个任务仅记录交付文档即可
+        3. 交付方式：最终交付文档通过 attempt_completion 工具输出
         2. 内容完整性： 在“任务分解文档”中，每个子任务都必须具备以下要素：
             * 任务名称：简短而清晰。
             * 输入契约：包含前置依赖，输入数据，环境依赖。
@@ -676,7 +575,6 @@ class AgenticAsk(BaseAgent):
             * 不能在没有澄清需求的情况下直接进行任务分解。如果需求有任何不确定性，你的首要任务就是提出问题。
             * 不允许跳过现有组件检索直接设计
             * 不允许在工具未返回时假设系统状态
-            * 不允许使用较为灵活的 execute_command 工具修改和新增文件
             * 最终交付方案不允许通过
         4. 失败处理：如果你判断需求在现有技术条件下无法实现，请立即停止任务，并在输出中明确说明原因，而不是提供一个无效的方案。
         """
@@ -693,9 +591,8 @@ class AgenticAsk(BaseAgent):
             {"role": "system", "content": self._system_prompt_rules.prompt()}
         ]
 
-        printer.print_key_value(
-            {"长度(tokens)": f"{count_tokens(json.dumps(conversations, ensure_ascii=False))}"}, title="系统提示词"
-        )
+        printer.print_text(f"📝 系统提示词长度(token): {count_tokens(json.dumps(conversations, ensure_ascii=False))}",
+                           style="green")
 
         if self.conversation_config.action == "resume":
             current_conversation = self.conversation_manager.get_current_conversation()
@@ -708,7 +605,7 @@ class AgenticAsk(BaseAgent):
                             "role": message['role'],
                             "content": message['content']
                         })
-                printer.print_text(f"恢复对话，已有 {len(current_conversation['messages'])} 条现有消息", style="green")
+                printer.print_text(f"📂 恢复对话，已有 {len(current_conversation['messages'])} 条现有消息", style="green")
         if self.conversation_manager.get_current_conversation_id() is None:
             conv_id = self.conversation_manager.create_conversation(name=self.conversation_config.query,
                                                                     description=self.conversation_config.query)
@@ -739,13 +636,12 @@ class AgenticAsk(BaseAgent):
 
         while True:
             iteration_count += 1
-            if iteration_count % 5 == 0:
-                conversations.append({"role": "system", "content": self._system_prompt_rules.prompt()})  # 强化规则记忆
+            if iteration_count % 20 == 0:
+                conversations.append({"role": "user", "content": self._system_prompt_rules.prompt()})  # 强化规则记忆
             tool_executed = False
             last_message = conversations[-1]
-            printer.print_key_value(
-                {"当前": f"第 {iteration_count} 轮", "历史会话长度": f"{len(conversations)}"}, title="LLM 交互循环"
-            )
+            printer.print_text(f"🔄 当前为第 {iteration_count} 轮对话, 历史会话长度(Context):{len(conversations)}",
+                               style="green")
 
             if last_message["role"] == "assistant":
                 if should_yield_completion_event:
@@ -916,21 +812,17 @@ class AgenticAsk(BaseAgent):
                     yield WindowLengthChangeEvent(tokens_used=total_tokens)
 
                 # 添加系统提示，要求LLM必须使用工具或明确结束，而不是直接退出
-                printer.print_text("正在添加系统提示: 请使用工具或尝试直接生成结果", style="green")
+                printer.print_text("💡 正在添加系统提示: 请使用工具或尝试直接生成结果", style="green")
 
                 conversations.append({
                     "role": "user",
-                    "content": "NOTE: You must use an appropriate tool (such as read_file, write_to_file, "
-                               "execute_command, etc.) or explicitly complete the task (using attempt_completion). Do "
-                               "not provide text responses without taking concrete actions. Please select a suitable "
-                               "tool to continue based on the user's task."
+                    "content": "注意：您必须使用适当的工具或明确完成任务（使用 attempt_completion）。"
+                               "不要在不采取具体行动的情况下提供文本回复。请根据用户的任务选择合适的工具继续操作。"
                 })
                 self.conversation_manager.append_message_to_current(
                     role="user",
-                    content="NOTE: You must use an appropriate tool (such as read_file, write_to_file, "
-                            "execute_command, etc.) or explicitly complete the task (using attempt_completion). Do "
-                            "not provide text responses without taking concrete actions. Please select a suitable "
-                            "tool to continue based on the user's task.",
+                    content="注意：您必须使用适当的工具或明确完成任务（使用 attempt_completion）。"
+                            "不要在不采取具体行动的情况下提供文本回复。请根据用户的任务选择合适的工具继续操作。",
                     metadata={})
 
                 # 计算当前对话的总 token 数量并触发事件
@@ -938,10 +830,10 @@ class AgenticAsk(BaseAgent):
                 total_tokens = count_tokens(current_conversation_str)
                 yield WindowLengthChangeEvent(tokens_used=total_tokens)
                 # 继续循环，让 LLM 再思考，而不是 break
-                printer.print_text("持续运行 LLM 交互循环（保持不中断）", style="green")
+                printer.print_text("🔄 持续运行 LLM 交互循环（保持不中断）", style="green")
                 continue
 
-        printer.print_text(f"AgenticAsk 分析循环已完成，共执行 {iteration_count} 次迭代.")
+        printer.print_text(f"✅ AgenticEdit 分析循环已完成，共执行 {iteration_count} 次迭代.")
         save_formatted_log(self.args.source_dir, json.dumps(conversations, ensure_ascii=False),
                            "agentic_ask_conversation")
 
@@ -986,20 +878,18 @@ class AgenticAsk(BaseAgent):
                         self.args.source_dir, f"auto_coder_{latest_yaml_file}_{md5}",
                     )
                     if commit_message:
-                        printer.print_panel(content=f"Commit 成功", title="Commit 信息", center=True)
+                        printer.print_text(f"Commit 成功", style="green")
                 except Exception as err:
                     import traceback
                     traceback.print_exc()
-                    printer.print_panel(content=f"Commit 失败: {err}", title="Commit 信息", center=True)
+                    printer.print_text(f"Commit 失败: {err}", style="red")
         else:
-            printer.print_panel(content=f"未进行任何更改", title="Commit 信息", center=True)
+            printer.print_text(f"文件未进行任何更改, 无需 Commit", style="yellow")
 
     def run_in_terminal(self, request: AgenticEditRequest):
         project_name = os.path.basename(os.path.abspath(self.args.source_dir))
 
-        printer.print_key_value(
-            items={"项目名": f"{project_name}", "用户目标": f"{request.user_input}"}, title="Agentic Ask 开始运行"
-        )
+        printer.print_text(f"🚀 Agentic Ask 开始运行, 项目名: {project_name}, 用户目标: {request.user_input}")
 
         # 用于累计TokenUsageEvent数据
         accumulated_token_usage = {
@@ -1020,23 +910,21 @@ class AgenticAsk(BaseAgent):
                     accumulated_token_usage["input_tokens"] += last_meta.input_tokens_count
                     accumulated_token_usage["output_tokens"] += last_meta.generated_tokens_count
 
-                    printer.print_key_value(accumulated_token_usage)
+                    printer.print_text(f"📝 Token 使用: "
+                                       f"Input({last_meta.input_tokens_count})/"
+                                       f"Output({last_meta.generated_tokens_count})",
+                                       style="green")
 
                 elif isinstance(event, WindowLengthChangeEvent):
-                    # 显示当前会话的token数量
-                    printer.print_panel(
-                        content=f"当前会话总 tokens: {event.tokens_used}", title="Window Length Change", center=True
-                    )
+                    printer.print_text(f"📝 当前 Token 总用量: {event.tokens_used}", style="green")
 
                 elif isinstance(event, LLMThinkingEvent):
-                    # Render thinking within a less prominent style, maybe grey?
-                    printer.print_panel(content=f"{event.text}", title="LLM Thinking", center=True)
+                    # 以不太显眼的样式（比如灰色）呈现思考内容
+                    think_text = f"[grey]{event.text}[/grey]"
+                    printer.print_panel(content=think_text, title="💭 LLM Thinking", center=True)
 
                 elif isinstance(event, LLMOutputEvent):
-                    # Print regular LLM output, potentially as markdown if needed later
-                    printer.print_panel(
-                        content=f"{event.text}", title="LLM Output", center=True
-                    )
+                    printer.print_panel(content=f"{event.text}", title="💬 LLM Output", center=True)
 
                 elif isinstance(event, ToolCallEvent):
                     # 不显示 AttemptCompletionTool 结果
@@ -1069,7 +957,7 @@ class AgenticAsk(BaseAgent):
 
                     def _format_content(_content):
                         if len(_content) > 500:
-                            return f"{_content[:200]}\n......\n{_content[-200:]}"
+                            return f"{_content[:200]}\n\n\n......\n\n\n{_content[-200:]}"
                         else:
                             return _content
 
