@@ -17,7 +17,7 @@ from autocoder_nano.utils.formatted_log_utils import save_formatted_log
 from autocoder_nano.utils.git_utils import get_uncommitted_changes
 from autocoder_nano.utils.printer_utils import Printer
 from autocoder_nano.agent.agentic_edit_tools import (  # Import specific resolvers
-    BaseToolResolver, ReadFileToolResolver,
+    BaseToolResolver,
     SearchFilesToolResolver, ListFilesToolResolver,
     AttemptCompletionToolResolver
 )
@@ -27,7 +27,6 @@ printer = Printer()
 
 
 COST_TOOL_RESOLVER_MAP: Dict[Type[BaseTool], Type[BaseToolResolver]] = {
-    ReadFileTool: ReadFileToolResolver,
     SearchFilesTool: SearchFilesToolResolver,
     ListFilesTool: ListFilesToolResolver,
     AttemptCompletionTool: AttemptCompletionToolResolver,  # Will stop the loop anyway
@@ -64,7 +63,7 @@ class AgenticCost(BaseAgent):
     @prompt()
     def _system_prompt_role(self):
         """
-        # 技术经济分析师 (Techno-Economic Analyst) Agent
+        # 技术经济分析师 Agent
 
         ## 核心身份与职责
 
@@ -72,25 +71,19 @@ class AgenticCost(BaseAgent):
         你不是代码执行者，而是决策前的“计算器”和“导航仪”，确保整个多智能体系统以最高性价比的方式启动和运行。
 
         # Multi-Agent系统全角色说明
-        - 老板 agent_manager：整个agent架构的的管理者, 任务的发起者
-            - 首席技术官 agent_cto：技术方案的主导者，选择最佳的技术方案及成本方案
-                - 技术研究员 agent_report：通过多rag与联网搜索结合的DeepResearch，用于深度研究某个技术架构，技术难题。
-                - 技术经济分析员 agent_cost：对整个需求做初步的难度判断，快速评估用户需求的综合难度与成本，提供下一步行动的决策依据。
-            - 产品经理 agent_ask：针对用户需求，做需求澄清，系统设计以及任务拆解，生成最终交付文档
-                - 研发工程师 agent_edit：编写基础设施，前端及后端的相关代码
-                - 测试专家 agent_test：编写测试脚本，进行代码功能测试
-                - 代码审核专家 agent_review：对研发工程师agent生成的代码进行多方面的审核
-                - 运维工程师 agent_devops：与Git/服务器/容器等关联，提交管理PR，CI/CD，部署以及基础设施的管理
+
+        - 技术经济分析师 agent_cost：对整个需求做初步的难度判断，快速评估用户需求的综合难度与成本，提供下一步行动的决策依据。
+        - 领域研究员 agent_report：通过多rag与联网搜索结合的DeepResearch，用于深度研究某个技术架构，技术难题。
+        - 产品经理 agent_ask：针对用户需求，做需求澄清，系统设计以及任务拆解，生成最终交付文档
+        - 研发工程师 agent_edit：编写基础设施，前端及后端的相关代码
 
         # 核心目标
 
         你的所有分析都必须围绕以下四个关键决策点展开：
 
-        - 难度判断：初步判断该需求的描述清晰度和技术实现难度（低/中/高/极高）。
-        - 研究必要性：决定是否需触发 agent_report (技术研究员) 进行深度研究。
-        - 澄清必要性：决定是否需触发 agent_ask (产品经理) 与用户进行需求澄清。
-        - 审核必要性：决定是否需触发 agent_review（代码审核专家）进行代码审核操作。
-        - 流程必要性：决定是否需触发 agent_devops（运维工程师）进行部署上线等操作。
+        - 难度判断：初步判断该需求的描述清晰度和技术实现难度（低/中/高/极高）
+        - 研究必要性：决定是否需触发 agent_report (技术研究员) 进行深度研究
+        - 澄清必要性：决定是否需触发 agent_ask (产品经理) 与用户进行需求澄清
 
         # 工作流与决策逻辑
 
@@ -98,21 +91,21 @@ class AgenticCost(BaseAgent):
 
         ## 第一步：需求复杂度分析
 
-        - 分析需求的技术范围（是否涉及前后端，基础设施，复杂算法）。
-            - 通过 list_files 工具递归列出项目目录，可以看出该项目基本规模，目录结构，使用语言，是否涉及前后端等等
-        - 分析需求的明确性（需求描述是否清晰，无歧义，有明确的输入输出）。
+        - 分析需求的技术范围（是否涉及前后端，基础设施，复杂算法）
+            - 通过 list_files 工具递归列出项目目录，初步进行以下判断
+                - 项目基本规模（文件数），目录结构，使用何种编程语言（代码文件后缀）
+                - 项目类型：前端项目，后端项目，Cli 工具脚本
+        - 分析需求的明确性（需求描述是否清晰，无歧义，有明确的输入输出）
             - 需求是否带上了明确的代码文件名，函数名，类名，以及改动点是否明确
             - 需求中是否带有明确的 "优化" "提升速度" 等对性能有要求的字眼
-            - 需求中时候明确出现了使用某技术栈进行任务的字眼
-        - 分析需求的依赖项（是否需要外部API，特殊数据库，特定许可）。
+            - 需求中是否明确出现了使用某技术栈进行任务的字眼
+            - 需求中是否明确提出了研究某种事物
+        - 分析需求的依赖项（是否需要外部API，特殊数据库，特定许可）
 
         ## 第二步：做出关键决策
 
-        - 需求涉及未知技术栈，未验证的算法，极高的性能要求，【需深度研究】-> 建议调用 agent_report
+        - 需求涉及未知技术栈，未验证的算法，极高的性能要求，课题的研究【需深度研究】-> 建议调用 agent_report
         - 需求描述模糊，存在歧义，缺少关键细节（如UI样式，业务规则，边界条件），【需需求澄清】-> 建议调用 agent_ask
-        - 需求需要部署上线，需要管理基础设施，需要CI/CD流水线，【需完整DevOps】 -> 计划调用 agent_devops
-        - 需求如果是需要部署项目，或者对性能要求较高的项目，以及可能需要做大量变更，【需完整代码审核】 -> 建议调用 agent_review
-        - 需求是简单的脚本修改，代码片段生成，无需部署的简单类问题，【无需完整DevOps】 -> 仅需 agent_edit 和 agent_test
 
         # 最终输出格式
 
@@ -121,8 +114,6 @@ class AgenticCost(BaseAgent):
             "difficulty": "中",
             "need_research": false,
             "need_ask": true,
-            "agent_review": false,
-            "need_devops": true,
             "decision_rationale": "需求业务逻辑清晰，但缺少对并发用户数的明确要求，建议由agent_ask先行澄清。核心交易模块难度较高，建议使用GPT-4o编写以确保质量。"
         }
         ```
@@ -130,15 +121,12 @@ class AgenticCost(BaseAgent):
         - difficulty：可选值: "低", "中", "高", "极高"
         - need_research： 布尔值: true / false
         - need_ask：布尔值: true / false
-        - need_devops：布尔值: true / false
-        - agent_review：布尔值: true / false
         - decision_rationale：原因说明，在20字以内
 
         # 约束与核心规则
 
         - 果断明确：你的决策必须是非黑即白的（true/false），不允许使用 “可能”，“也许” 等模糊词汇。
-        - 效率优先：你的分析应在最短时间内完成（模拟：<30秒），本身不应消耗过多Token成本。
-        - 全局最优：你的模型推荐应站在整个项目总成本的角度，而非单个环节。
+        - 效率优先：你的分析应在最短时间内完成，进行初步判断，本身不应消耗过多Token成本。
         - 最后使用 attempt_completion 工具输出 json 结果
         """
 
@@ -168,30 +156,6 @@ class AgenticCost(BaseAgent):
 
         # 工具列表
 
-        ## read_file（读取文件）
-        描述：
-        - 请求读取指定路径文件的内容。
-        - 当需要检查现有文件的内容（例如分析代码，查看文本文件或从配置文件中提取信息）且不知道文件内容时使用此工具。
-        - 仅能从 Markdown，TXT，以及代码文件中提取纯文本，不要读取其他格式文件。
-        参数：
-        - path（必填）：要读取的文件路径（相对于当前工作目录{{ current_project }}）。
-        用法说明：
-        <read_file>
-        <path>文件路径在此</path>
-        </read_file>
-        用法示例：
-        场景一：读取代码文件
-        目标：查看指定路径文件的具体内容。
-        <read_file>
-        <path>src/autocoder_nane/auto_coder_nano.py</path>
-        </read_file>
-        场景二：读取配置文件
-        目标：检查项目的配置文件，例如 package.json。
-        思维过程：这是一个非破坏性操作，使用 read_file 工具可以读取 package.json 文件内容，以了解项目依赖或脚本信息。
-        <read_file>
-        <path>package.json</path>
-        </read_file>
-
         ## search_files（搜索文件）
         描述：
         - 在指定目录的文件中执行正则表达式搜索，输出包含每个匹配项及其周围的上下文结果。
@@ -277,8 +241,6 @@ class AgenticCost(BaseAgent):
             "difficulty": "中",
             "need_research": false,
             "need_ask": true,
-            "agent_review": false,
-            "need_devops": true,
             "decision_rationale": "需求业务逻辑清晰，但缺少对并发用户数的明确要求，建议由agent_ask先行澄清。核心交易模块难度较高，建议使用GPT-4o编写以确保质量。"
         }
         </result>
@@ -301,9 +263,8 @@ class AgenticCost(BaseAgent):
             {"role": "system", "content": self._system_prompt_tools.prompt()}
         ]
 
-        printer.print_key_value(
-            {"长度(tokens)": f"{count_tokens(json.dumps(conversations, ensure_ascii=False))}"}, title="系统提示词"
-        )
+        printer.print_text(f"📝 系统提示词长度(token): {count_tokens(json.dumps(conversations, ensure_ascii=False))}",
+                           style="green")
 
         if self.conversation_config.action == "resume":
             current_conversation = self.conversation_manager.get_current_conversation()
@@ -316,7 +277,7 @@ class AgenticCost(BaseAgent):
                             "role": message['role'],
                             "content": message['content']
                         })
-                printer.print_text(f"恢复对话，已有 {len(current_conversation['messages'])} 条现有消息", style="green")
+                printer.print_text(f"📂 恢复对话，已有 {len(current_conversation['messages'])} 条现有消息", style="green")
         if self.conversation_manager.get_current_conversation_id() is None:
             conv_id = self.conversation_manager.create_conversation(name=self.conversation_config.query,
                                                                     description=self.conversation_config.query)
@@ -349,9 +310,8 @@ class AgenticCost(BaseAgent):
             iteration_count += 1
             tool_executed = False
             last_message = conversations[-1]
-            printer.print_key_value(
-                {"当前": f"第 {iteration_count} 轮", "历史会话长度": f"{len(conversations)}"}, title="LLM 交互循环"
-            )
+            printer.print_text(f"🔄 当前为第 {iteration_count} 轮对话, 历史会话长度(Context):{len(conversations)}",
+                               style="green")
 
             if last_message["role"] == "assistant":
                 if should_yield_completion_event:
@@ -522,21 +482,17 @@ class AgenticCost(BaseAgent):
                     yield WindowLengthChangeEvent(tokens_used=total_tokens)
 
                 # 添加系统提示，要求LLM必须使用工具或明确结束，而不是直接退出
-                printer.print_text("正在添加系统提示: 请使用工具或尝试直接生成结果", style="green")
+                printer.print_text("💡 正在添加系统提示: 请使用工具或尝试直接生成结果", style="green")
 
                 conversations.append({
                     "role": "user",
-                    "content": "NOTE: You must use an appropriate tool (such as read_file, write_to_file, "
-                               "execute_command, etc.) or explicitly complete the task (using attempt_completion). Do "
-                               "not provide text responses without taking concrete actions. Please select a suitable "
-                               "tool to continue based on the user's task."
+                    "content": "注意：您必须使用适当的工具或明确完成任务（使用 attempt_completion）。"
+                               "不要在不采取具体行动的情况下提供文本回复。请根据用户的任务选择合适的工具继续操作。"
                 })
                 self.conversation_manager.append_message_to_current(
                     role="user",
-                    content="NOTE: You must use an appropriate tool (such as read_file, write_to_file, "
-                            "execute_command, etc.) or explicitly complete the task (using attempt_completion). Do "
-                            "not provide text responses without taking concrete actions. Please select a suitable "
-                            "tool to continue based on the user's task.",
+                    content="注意：您必须使用适当的工具或明确完成任务（使用 attempt_completion）。"
+                            "不要在不采取具体行动的情况下提供文本回复。请根据用户的任务选择合适的工具继续操作。",
                     metadata={})
 
                 # 计算当前对话的总 token 数量并触发事件
@@ -544,10 +500,10 @@ class AgenticCost(BaseAgent):
                 total_tokens = count_tokens(current_conversation_str)
                 yield WindowLengthChangeEvent(tokens_used=total_tokens)
                 # 继续循环，让 LLM 再思考，而不是 break
-                printer.print_text("持续运行 LLM 交互循环（保持不中断）", style="green")
+                printer.print_text("🔄 持续运行 LLM 交互循环（保持不中断）", style="green")
                 continue
 
-        printer.print_text(f"Agentic Cost 分析循环已完成，共执行 {iteration_count} 次迭代.")
+        printer.print_text(f"✅ AgenticEdit 分析循环已完成，共执行 {iteration_count} 次迭代.")
         save_formatted_log(self.args.source_dir, json.dumps(conversations, ensure_ascii=False),
                            "agentic_cost_conversation")
 
@@ -559,9 +515,7 @@ class AgenticCost(BaseAgent):
     def run_in_terminal(self, request: AgenticEditRequest) -> str:
         project_name = os.path.basename(os.path.abspath(self.args.source_dir))
 
-        printer.print_key_value(
-            items={"项目名": f"{project_name}", "用户目标": f"{request.user_input}"}, title="Agentic Cost 开始运行"
-        )
+        printer.print_text(f"🚀 Agentic Cost 开始运行, 项目名: {project_name}, 用户目标: {request.user_input}")
 
         # 用于累计TokenUsageEvent数据
         accumulated_token_usage = {
@@ -573,7 +527,7 @@ class AgenticCost(BaseAgent):
         cost_result = "{}"
 
         try:
-            self.apply_pre_changes()  # 在开始 Agentic Ask 之前先判断是否有未提交变更,有变更则直接退出
+            self.apply_pre_changes()  # 在开始 Agentic Cost 之前先判断是否有未提交变更,有变更则直接退出
             event_stream = self.analyze(request)
             for event in event_stream:
                 if isinstance(event, TokenUsageEvent):
@@ -584,23 +538,21 @@ class AgenticCost(BaseAgent):
                     accumulated_token_usage["input_tokens"] += last_meta.input_tokens_count
                     accumulated_token_usage["output_tokens"] += last_meta.generated_tokens_count
 
-                    printer.print_key_value(accumulated_token_usage)
+                    printer.print_text(f"📝 Token 使用: "
+                                       f"Input({last_meta.input_tokens_count})/"
+                                       f"Output({last_meta.generated_tokens_count})",
+                                       style="green")
 
                 elif isinstance(event, WindowLengthChangeEvent):
-                    # 显示当前会话的token数量
-                    printer.print_panel(
-                        content=f"当前会话总 tokens: {event.tokens_used}", title="Window Length Change", center=True
-                    )
+                    printer.print_text(f"📝 当前 Token 总用量: {event.tokens_used}", style="green")
 
                 elif isinstance(event, LLMThinkingEvent):
-                    # Render thinking within a less prominent style, maybe grey?
-                    printer.print_panel(content=f"{event.text}", title="LLM Thinking", center=True)
+                    # 以不太显眼的样式（比如灰色）呈现思考内容
+                    think_text = f"[grey]{event.text}[/grey]"
+                    printer.print_panel(content=think_text, title="💭 LLM Thinking", center=True)
 
                 elif isinstance(event, LLMOutputEvent):
-                    # Print regular LLM output, potentially as markdown if needed later
-                    printer.print_panel(
-                        content=f"{event.text}", title="LLM Output", center=True
-                    )
+                    printer.print_panel(content=f"{event.text}", title="💬 LLM Output", center=True)
 
                 elif isinstance(event, ToolCallEvent):
                     # 不显示 AttemptCompletionTool 结果
@@ -627,7 +579,7 @@ class AgenticCost(BaseAgent):
 
                     def _format_content(_content):
                         if len(_content) > 500:
-                            return f"{_content[:200]}\n......\n{_content[-200:]}"
+                            return f"{_content[:200]}\n\n\n......\n\n\n{_content[-200:]}"
                         else:
                             return _content
 
