@@ -6,14 +6,12 @@ from autocoder_nano.agent.agentic_edit_types import ToolResult, AttemptCompletio
 from autocoder_nano.actypes import AutoCoderArgs
 
 if typing.TYPE_CHECKING:
-    from autocoder_nano.agent.agentic_edit import AgenticEdit
-    from autocoder_nano.agent.agentic_ask import AgenticAsk
-    from autocoder_nano.agent.agentic_cost import AgenticCost
+    from autocoder_nano.agent.agentic_runtime import AgenticRuntime
 
 
 class AttemptCompletionToolResolver(BaseToolResolver):
     def __init__(
-            self, agent: Optional[Union['AgenticEdit', 'AgenticAsk', 'AgenticCost']],
+            self, agent: Optional[Union['AgenticRuntime']],
             tool: AttemptCompletionTool, args: AutoCoderArgs
     ):
         super().__init__(agent, tool, args)
