@@ -8,15 +8,14 @@ from autocoder_nano.utils.printer_utils import Printer
 from autocoder_nano.utils.shell_utils import run_cmd_subprocess
 
 if typing.TYPE_CHECKING:
-    from autocoder_nano.agent.agentic_edit import AgenticEdit
-    from autocoder_nano.agent.agentic_ask import AgenticAsk
+    from autocoder_nano.agent.agentic_runtime import AgenticRuntime
 
 
 printer = Printer()
 
 
 class ExecuteCommandToolResolver(BaseToolResolver):
-    def __init__(self, agent: Optional[Union['AgenticEdit', 'AgenticAsk']], tool: ExecuteCommandTool,
+    def __init__(self, agent: Optional[Union['AgenticRuntime']], tool: ExecuteCommandTool,
                  args: AutoCoderArgs):
         super().__init__(agent, tool, args)
         self.tool: ExecuteCommandTool = tool  # For type hinting
