@@ -10,14 +10,12 @@ from autocoder_nano.actypes import AutoCoderArgs
 from autocoder_nano.utils.sys_utils import default_exclude_dirs
 
 if typing.TYPE_CHECKING:
-    from autocoder_nano.agent.agentic_edit import AgenticEdit
-    from autocoder_nano.agent.agentic_ask import AgenticAsk
-    from autocoder_nano.agent.agentic_cost import AgenticCost
+    from autocoder_nano.agent.agentic_runtime import AgenticRuntime
 
 
 class SearchFilesToolResolver(BaseToolResolver):
     def __init__(
-            self, agent: Optional[Union['AgenticEdit', 'AgenticAsk', 'AgenticCost']],
+            self, agent: Optional[Union['AgenticRuntime']],
             tool: SearchFilesTool, args: AutoCoderArgs
     ):
         super().__init__(agent, tool, args)
